import { JwtPayload, VerifyOptions } from 'jsonwebtoken';
import { TranslationModel } from 'mobx-i18n';
import { GetServerSidePropsContext, GetServerSidePropsResult } from 'next';
import { ParsedUrlQuery } from 'querystring';
import { DataObject, Middleware } from '../compose';
export declare function errorLogger<I extends DataObject, O extends DataObject = {}>(context: GetServerSidePropsContext<I>, next: () => Promise<GetServerSidePropsResult<O>>): Promise<GetServerSidePropsResult<O>>;
export interface RouteProps<T extends ParsedUrlQuery = {}> {
    route: Pick<GetServerSidePropsContext<T>, 'resolvedUrl' | 'params' | 'query' | 'locales'>;
}
export declare function router<I extends DataObject, O extends DataObject = {}>(context: GetServerSidePropsContext<I>, next: () => Promise<GetServerSidePropsResult<O>>): Promise<GetServerSidePropsResult<RouteProps<I> & O>>;
export interface JWTProps<T extends DataObject = {}> {
    jwtPayload?: JwtPayload & T;
}
export declare function jwtVerifier<I extends DataObject, O extends DataObject = {}>(tokenKey?: string, secretKey?: string, options?: VerifyOptions): Middleware<I, O & JWTProps>;
export declare function cache<I extends DataObject, O extends DataObject = {}>(oneInterval?: number, allInterval?: number): Middleware<I, O>;
export declare function translator<I extends DataObject, O extends DataObject = {}>(i18n: TranslationModel<string, string>): Middleware<I, O>;
