import { DataObject, Middleware } from '../compose';
export type OAuth2Ticket = {
    code: string;
    state?: string;
    [key: string]: string;
};
export interface OAuth2Option {
    signInURL: (pageURL: string) => string;
    accessToken: (ticket: OAuth2Ticket) => Promise<string>;
    userProfile: (token: string) => Promise<DataObject>;
    tokenKey?: string;
}
export interface OAuth2Props<T extends DataObject> {
    token: string;
    user: T;
}
export declare function oauth2Signer<I extends DataObject, O extends DataObject = {}>({ signInURL, accessToken, userProfile, tokenKey }: OAuth2Option): Middleware<I, O>;
export type GitHubAPIOperation = 'admin' | 'write' | 'read' | 'delete';
export type GitHubOAuthScope = `repo${'' | ':status' | '_deployment' | ':invite'}` | 'public_repo' | 'security_events' | `${Exclude<GitHubAPIOperation, 'delete'>}:${'repo_hook' | 'org' | 'public_key' | 'gpg_key'}` | 'admin:org_hook' | 'gist' | 'notifications' | `user${'' | ':email' | ':follow'}` | `read:${'user' | 'project'}` | 'project' | 'delete_repo' | `${Exclude<GitHubAPIOperation, 'admin'>}:packages` | 'codespace' | 'workflow';
/**
 * @see {@link https://docs.github.com/en/apps/oauth-apps/building-oauth-apps/authorizing-oauth-apps#web-application-flow}
 */
export interface GitHubOAuthOption extends Partial<Record<'rootBaseURL' | 'apiBaseURL' | 'login', string>>, Record<'client_id' | 'client_secret', string> {
    scopes?: GitHubOAuthScope[];
    allow_signup?: boolean;
}
export declare function githubOAuth2<I extends DataObject, O extends DataObject = {}>({ rootBaseURL, apiBaseURL, client_id, client_secret, scopes, allow_signup }: GitHubOAuthOption): Middleware<I, O>;
